summaryrefslogtreecommitdiffabout
path: root/include/opkele/types.h
Side-by-side diff
Diffstat (limited to 'include/opkele/types.h') (more/less context) (ignore whitespace changes)
-rw-r--r--include/opkele/types.h7
1 files changed, 3 insertions, 4 deletions
diff --git a/include/opkele/types.h b/include/opkele/types.h
index ca07df5..d959021 100644
--- a/include/opkele/types.h
+++ b/include/opkele/types.h
@@ -12,4 +12,4 @@
#include <map>
-#include <memory>
#include <set>
+#include <opkele/tr1-mem.h>
@@ -20,3 +20,2 @@ namespace opkele {
using std::ostream;
- using std::auto_ptr;
using std::multimap;
@@ -110,5 +109,5 @@ namespace opkele {
/**
* the auto_ptr<> for association_t object type
*/
- typedef auto_ptr<association_t> assoc_t;
+ typedef tr1mem::shared_ptr<association_t> assoc_t;
@@ -110,5 +109,5 @@ namespace opkele {
/**
- * the auto_ptr<> for association_t object type
+ * the shared_ptr<> for association_t object type
*/